#
#  Pehong Chen, University of California, Berkeley (phc@renoir.berkeley.edu)
#
#      modified for distribution, monardo@renoir.berkeley.edu
#
CROSSDIR = /dsrg/bammi/cross-gcc
CROSSBIN = $(CROSSDIR)/bin
CROSSLIB = $(CROSSDIR)/lib
CROSSINC = $(CROSSDIR)/include

CC	      = $(CROSSBIN)/cgcc
LINKER	      = $(CROSSBIN)/cgcc

VPATH         = ..

DEST	      = /usr/local

MANDIR	      = /usr/man/manl

MANUAL	      =

HDRS	      = align.h \
		arith.h \
		box.h \
		boxlists.h \
		char.h \
		cmds.h \
		cond.h \
		def.h \
		dvi.h \
		eq.h \
		eqstack.h \
		error.h \
		eval.h \
		evalstack.h \
		expand.h \
		file.h \
		fmt.h \
		hash.h \
		heap.h \
		hyph.h \
		io.h \
		math.h \
		mathlists.h \
		mlst-hlst.h \
		pack.h \
		page.h \
		par.h \
		print.h \
		scan.h \
		str.h \
		tex.h \
		texext.h \
		tfm.h \
		token.h \
		tokenlists.h \
		tokenstack.h

# Option for compiling SUN 68010 code with a 68020 CPU
68010CFLAGS   = -m68010 -L/usr.MC68010/lib -Qpath /usr.MC68010/cstart

# 16-bit word
#CFLAGS	      = -O -I. -v -DINIT
CFLAGS	      = -O -DSTAT -DINIT -fomit-frame-pointer -fcombine-regs
#
# for statex define
#
#CFLAGS	      = -O -I. -v -DINIT -DSTAT -fomit-frame-pointer -fcombine-regs -fforce-mem \
#-fforce-addr

# 32-bit word
#CFLAGS	      = -O -DBIG
#CFLAGS	      = -O -DBIG $(68010CFLAGS)

# 64-bit word
#CFLAGS	      = -O -DBIGG
#CFLAGS	      = -O -DBIGG $(68010CFLAGS)

LDFLAGS	      = $(CFLAGS) -v -s -X -x

LIBS	      = -liio


MAKEFILE      = Makefile

OBJS	      = align.o \
		arith.o \
		box.o \
		boxlists.o \
		char.o \
		cmds.o \
		cond.o \
		def.o \
		dvi.o \
		eq.o \
		eqstack.o \
		error.o \
		eval.o \
		evalstack.o \
		expand.o \
		file.o \
		fmt.o \
		hash.o \
		heap.o \
		hyph.o \
		io.o \
		math.o \
		mathlists.o \
		mlst-hlst.o \
		pack.o \
		page.o \
		par.o \
		print.o \
		scan.o \
		str.o \
		tex.o \
		texext.o \
		tfm.o \
		token.o \
		tokenlists.o \
		tokenstack.o 
#		time.o

PRINT	      = tgrind -c

PROGRAM	      = initex.ttp

SRCS	      = align.c \
		arith.c \
		box.c \
		boxlists.c \
		char.c \
		cmds.c \
		cond.c \
		def.c \
		dvi.c \
		eq.c \
		eqstack.c \
		error.c \
		eval.c \
		evalstack.c \
		expand.c \
		file.c \
		fmt.c \
		hash.c \
		heap.c \
		hyph.c \
		io.c \
		math.c \
		mathlists.c \
		mlst-hlst.c \
		pack.c \
		page.c \
		par.c \
		print.c \
		scan.c \
		str.c \
		tex.c \
		texext.c \
		tfm.c \
		token.c \
		tokenlists.c \
		tokenstack.c

$(PROGRAM):     $(OBJS)
		@rm -f $(PROGRAM)
		$(LINKER) $(LDFLAGS) $(OBJS) $(LIBS) -o $(PROGRAM)
#		@size $(PROGRAM)

install:	$(PROGRAM)
		install -c -s -m 0755 $(PROGRAM) $(DEST)
		@ls -lgs $(DEST)/$(PROGRAM)

clean:;		rm -f $(OBJS) core

depend:;	@rm -f .#*.[chly]
		mkmf -f $(MAKEFILE) PROGRAM=$(PROGRAM) DEST=$(DEST)

index:;		@ctags -wx $(HDRS) $(SRCS)

print:;		@$(PRINT) $(HDRS) $(SRCS)

program:        $(PROGRAM)

tags:           $(HDRS) $(SRCS); @ctags $(HDRS) $(SRCS)

update:		$(DEST)/$(PROGRAM)

$(DEST)/$(PROGRAM): $(SRCS) $(HDRS)
		@make -f $(MAKEFILE) DEST=$(DEST) install

.DEFAULT:;
###
align.o: tex.h cmds.h heap.h arith.h eq.h eqstack.h hash.h \
	token.h tokenstack.h scan.h evalstack.h box.h pack.h math.h \
	mlst-hlst.h error.h align.h
arith.o: tex.h print.h arith.h
box.o: tex.h texext.h arith.h heap.h char.h str.h \
	eq.h hash.h tfm.h print.h math.h box.h tokenlists.h
boxlists.o: tex.h cmds.h heap.h eq.h eqstack.h def.h box.h \
	tokenstack.h token.h scan.h tokenlists.h evalstack.h tfm.h pack.h \
	page.h math.h io.h print.h error.h boxlists.h
char.o: tex.h char.h
cmds.o: tex.h texext.h heap.h eq.h eqstack.h str.h \
	hash.h token.h tokenlists.h tokenstack.h scan.h evalstack.h def.h \
	cond.h expand.h box.h boxlists.h tfm.h math.h mathlists.h align.h \
	error.h print.h cmds.h
cond.o: tex.h cmds.h heap.h box.h eq.h eqstack.h hash.h \
	token.h tokenlists.h scan.h tokenstack.h evalstack.h file.h print.h \
	error.h cond.h
def.o: tex.h cmds.h heap.h io.h eq.h hash.h eqstack.h \
	evalstack.h token.h scan.h tokenstack.h expand.h arith.h str.h \
	box.h boxlists.h tokenlists.h file.h tfm.h dvi.h page.h print.h \
	error.h def.h
dvi.o: tex.h texext.h heap.h str.h io.h eq.h box.h \
	scan.h tfm.h file.h pack.h print.h error.h dvi.h 
eq.o: tex.h cmds.h heap.h char.h hash.h box.h print.h \
	error.h eq.h 
eqstack.o: tex.h cmds.h heap.h eq.h token.h tokenstack.h \
	tokenlists.h print.h error.h eqstack.h
error.o: tex.h tokenstack.h token.h eq.h io.h print.h \
	error.h str.h 
eval.o: tex.h cmds.h heap.h char.h tfm.h eq.h eqstack.h \
	hash.h token.h scan.h tokenstack.h evalstack.h box.h boxlists.h \
	math.h mathlists.h cond.h def.h dvi.h pack.h page.h par.h print.h \
	error.h eval.h
evalstack.o: tex.h cmds.h heap.h tokenstack.h eq.h box.h \
	page.h print.h error.h evalstack.h
expand.o: tex.h cmds.h heap.h io.h eq.h hash.h box.h \
	tokenstack.h scan.h token.h tokenlists.h cond.h file.h print.h \
	error.h expand.h
file.o: tex.h cmds.h heap.h char.h eq.h token.h scan.h \
	tokenstack.h str.h fmt.h io.h print.h error.h file.h 
fmt.o: tex.h texext.h heap.h token.h eq.h box.h \
	eqstack.h hash.h file.h tfm.h str.h hyph.h io.h print.h error.h \
	fmt.h
hash.o: tex.h cmds.h heap.h box.h scan.h eq.h io.h math.h \
	boxlists.h str.h error.h hash.h
heap.o: tex.h eq.h arith.h box.h token.h tokenlists.h \
	evalstack.h par.h page.h print.h error.h heap.h
hyph.o: tex.h cmds.h heap.h token.h eq.h str.h tfm.h \
	box.h scan.h tokenstack.h par.h print.h error.h hyph.h
io.o: tex.h char.h tokenstack.h print.h io.h 
math.o: tex.h heap.h eq.h scan.h evalstack.h arith.h \
	str.h box.h tfm.h print.h pack.h math.h
mathlists.o: tex.h cmds.h heap.h arith.h eq.h eqstack.h \
	evalstack.h token.h tokenstack.h scan.h tfm.h box.h pack.h math.h \
	mlst-hlst.h par.h page.h print.h error.h mathlists.h
mlst-hlst.o: tex.h heap.h arith.h scan.h eq.h box.h math.h \
	pack.h tfm.h print.h error.h mlst-hlst.h
pack.o: tex.h heap.h arith.h scan.h tokenstack.h eq.h \
	eqstack.h evalstack.h box.h tfm.h dvi.h print.h error.h pack.h
page.o: tex.h heap.h arith.h tokenstack.h tokenlists.h \
	eq.h eqstack.h evalstack.h scan.h expand.h box.h pack.h par.h math.h \
	dvi.h print.h error.h page.h
par.o: tex.h heap.h arith.h eq.h tfm.h tokenstack.h \
	evalstack.h box.h pack.h hyph.h print.h error.h par.h
print.o: tex.h texext.h eq.h char.h str.h io.h print.h
scan.o: tex.h cmds.h heap.h arith.h eq.h token.h \
	tokenstack.h evalstack.h char.h str.h box.h expand.h tfm.h dvi.h \
	print.h error.h page.h scan.h
str.o: tex.h io.h file.h error.h str.h
tex.o: tex.h texext.h cmds.h heap.h char.h str.h eq.h \
	hash.h evalstack.h eqstack.h tokenstack.h token.h box.h pack.h cond.h \
	io.h file.h tfm.h hyph.h dvi.h fmt.h error.h print.h page.h 
texext.o: tex.h cmds.h heap.h eq.h hash.h token.h box.h \
	scan.h def.h tokenstack.h tokenlists.h evalstack.h io.h str.h \
	file.h dvi.h print.h error.h texext.h
tfm.o: tex.h cmds.h heap.h arith.h eq.h hash.h box.h \
	scan.h token.h tokenstack.h io.h file.h print.h error.h tfm.h
token.o: tex.h cmds.h heap.h eq.h hash.h scan.h io.h \
	char.h box.h cond.h print.h error.h expand.h align.h tokenstack.h \
	token.h
tokenlists.o: tex.h cmds.h heap.h eq.h hash.h str.h box.h \
	token.h expand.h tokenstack.h io.h scan.h def.h file.h tfm.h print.h \
	error.h tokenlists.h
tokenstack.o: tex.h cmds.h heap.h eq.h def.h char.h io.h \
	token.h tokenlists.h box.h print.h error.h tokenstack.h
